from .ball_in_a_cup import BallInACup
from .humanoid_gait import HumanoidGait

BallInACup.register()
HumanoidGait.register()
